# coding: utf-8

"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""


from __future__ import absolute_import

import re  # noqa: F401
from typing import TYPE_CHECKING, Any

# python 2 and python 3 compatibility library
import six

from grid.openapi.api_client import ApiClient

if TYPE_CHECKING:
    from datetime import datetime
    from grid.openapi.models import *


class ConfigServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def config_service_get_config(self, **kwargs) -> 'V1GetConfigResponse':  # noqa: E501
        """config_service_get_config  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.config_service_get_config(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1GetConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.config_service_get_config_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.config_service_get_config_with_http_info(**kwargs)  # noqa: E501
            return data

    def config_service_get_config_with_http_info(self, **kwargs) -> 'V1GetConfigResponse':  # noqa: E501
        """config_service_get_config  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.config_service_get_config_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1GetConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method config_service_get_config" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/config', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1GetConfigResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from typing import Optional, List

from grid.sdk.datastores import DATASTORE_FSX_THROUGHPUT_ALIASES


def datastore_currently_creating_datastore(
    name: str, version: str, cluster: str, all_clusters: Optional[List[str]] = None
) -> str:
    res = f"We are creating {name} datastore (version {version}) on cluster {cluster}"
    if all_clusters is not None:
        res += f" not on these clusters: {all_clusters}."
    else:
        res += "."
    res += " Please use `grid datastore` to check the status."
    return res


def datastore_uploaded_successfully(name: str, version: str, cluster: str) -> str:
    return (
        f"Completed uploading {name} datastore (version {version}) on "
        f"cluster {cluster}. Your datastore will be available for use shortly."
    )


def datastore_fsx_total_throughput(throughput_alias: str, capacity_gib: int) -> str:
    return (
        f"You have created a high-performance datastore with throughput setting [{throughput_alias}] which "
        f"corresponds to {DATASTORE_FSX_THROUGHPUT_ALIASES[throughput_alias]}MB/s/TiB of storage. This means "
        f"that with your selected capacity of {capacity_gib}GiB, the total throughput available for the datastore "
        f"will be {DATASTORE_FSX_THROUGHPUT_ALIASES[throughput_alias] * capacity_gib / 1000}MB/s. Note that "
        f"high-performance datastores may burst over their nominal throughput rating."
    )
